poseidon2_compression

Function poseidon2_compression 

pub fn poseidon2_compression(left: FpBN256, right: FpBN256) -> FpBN256
Poseidon2 hash of two field elements using optimized compression mode

Arguments

  • left - First field element to hash
  • right - Second field element to hash

Returns

Returns the first element of the permutation result after adding the inputs.