pub fn derive_public_key(private_key: FpBN256) -> FpBN256Expand description
Derive a public key from a private key using Poseidon2 hash
Computes publicKey = Poseidon2(privateKey, 0) with domain separation value
3. Please note the 0 is used as padding as Poseidon2 hash does not support
T=1 inputs (over BN256).
Arguments
private_key- Private key scalar value
Returns
Returns the derived public key as a scalar value.